declare class Captcha {
    constructor(scene?: string);
    static Scene: any;
    static Ret: any;
    static hasLoadedScript: boolean;
    sendSmsVerificationCode(phone: string): Promise<any>;
    show(): Promise<any>;
}

declare const enum WeappAuthScope {
    BASE,
    USER_INFO
}

declare class Log {
    getLogger(category: string): object;

    catchGlobalErrors(): void;
}

declare class Mai {
    constructor(env: string, accountId: string, options?: {
        appName?: string;
        appVersion?: string;
        oauthApiBaseUrl?: string;
        consumerApiBaseUrl?: string;
        cdnBaseUrl?: string;
    });
 
    member: Member;
    weapp: Weapp;
    memberEvent: MemberEvent;
    log: Log;
    WeappAuthScope: typeof WeappAuthScope;
    OssImage: typeof OssImage;
    Captcha: typeof Captcha;
    wxH5: WxH5;
    wxWeapp: WxWeapp;
    envConfig: typeof envConfig;
    setAccountId(accountId: any): void;
}

declare class Member {
    signin(options: {
        appId?: string;
        scope?: WeappAuthScope;
        code?: string;
        iv?: string;
        encryptedData?: string;
        isGroup?: boolean;
        channelId?: string;
        accessToken?: string;
        callback?: (...params: any[]) => any;
        lang?: string;
    }): Promise<void>;

    addTags(tags: string[]): void;

    trackAffiliation(affiliateProgramId: string, inviterOpenId?: string): void;

    getDetail(extraFields?: ('Card' | 'Properties')[], withCache?: boolean): Promise<object>;

    searchPropertyInfo(options: {
        isDefault?: boolean;
        isVisible?: boolean;
        ids?: string[];
        names?: string[];
        propertyIds?: string[];
        listCondition?: {
            page?: number;
            perPage?: number;
            orderBy?: string[];
        };
    }): Promise<object[]>;

    setProperties(properties: object[]): Promise<object>;

    getChannelId(): string;
 
    getPhone(): string;
    
    getMemberId(): string;

    isActivated(): boolean;

    getSocial(): any;

    getNickname(): string;

    getOpenId(): string;
 
    getUnionId(): string;

    isSocialAuthorized(): boolean;

    isNewChannel(): boolean;
}

declare class MemberEvent {

    log(name: string, properties: any, cb: (...params: any[]) => any): void;

    logPageView(properties: {
        utmCampaign?: string;
        utmContent?: string;
        utmTerm?: string;
        utmMedium?: string;
        utmSource?: string;
        content?: string;
        url?: string;
        refererContent?: string;
        refererUrl?: string;
        redirectContent?: string;
        redirectUrl?: string;
        extra?: any;
    }, cb: (...params: any[]) => any): void;

    logPageOperate(properties: {
        utmSource?: string;
        utmContent?: string;
        utmMedium?: string;
        utmCampaign?: string;
        utmTerm?: string;
        pageContent?: string;
        url?: string;
        type: string;
        content: string;
        redirectContent?: string;
        redirectUrl?: string;
        extra?: any;
    }, cb: (...params: any[]) => any): void;
}

declare class OssImage {

    url: string;

    static source(url: string): OssImage;

    transformWechatAvatar(): OssImage;

    transformWechatQRCode(): OssImage;

    resolveDomain(): OssImage;

    removeDomain(): OssImage;
   
    resize(options: {
        m: 'lfit' | 'mfit' | 'fill' | 'pad' | 'fixed';
        w: number;
        h: number;
        l: number;
        s: number;
        limit: number;
        color: string;
        p: number;
    }): OssImage;
   
    circle(options: {
        r: number;
    }): OssImage;
   
    crop(options: {
        w: number;
        h: number;
        x: number;
        y: number;
        g: 'nw' | 'north' | 'ne' | 'west' | 'center' | 'east' | 'sw' | 'south' | 'se';
    }): OssImage;
  
    indexCrop(options: {
        x: number;
        y: number;
        i: number;
    }): OssImage;
   
    roundedCorners(options: {
        r: any;
    }): OssImage;
   
    autoOrient(orient: 0 | 1): OssImage;
    
    rotate(rotate: number): OssImage;
    
    blur(options: {
        r: number;
        s: number;
    }): OssImage;
  
    bright(bright: number): OssImage;
 
    contrast(contrast: number): OssImage;
   
    sharpen(sharpen: number): OssImage;
   
    format(format: string): OssImage;
    
    interlace(interlace: number): OssImage;
   
    quality(options: {
        q: number;
        Q: number;
    }): OssImage;
 
    watermark(options: {
        t: number;
        g: 'nw' | 'north' | 'ne' | 'west' | 'center' | 'east' | 'sw' | 'south' | 'se';
        x: number;
        y: number;
        voffset: number;
        image: string;
        text: string;
        type: 'wqy-zenhei' | 'wqy-microhei' | 'fangzhengshusong' | 'fangzhengkaiti' | 'fangzhengheiti' | 'fangzhengfangsong' | 'droidsansfallback';
        color: string;
        size: number;
        shadow: number;
        rotate: number;
        fill: number;
        order: number;
        align: 0 | 1 | 2;
        interval: number;
    }): OssImage;
}

declare var envConfig: {
    env: string;
    accountId: string;
    oauthApiBaseUrl: string;
    consumerApiBaseUrl: string;
    cdnBaseUrl: string;
};

declare var queue: any;

declare var pendingRequests: any;

declare var MAX_PENDING_REQUESTS: any;

declare function checkQueue(): void;

declare function normalizeHeaders(headers: any): void;

declare function lowerCaseHeaders(headers: any): void;

declare function encode(val: string): void;

declare function buildURL(url: string, params: any, paramsSerializer: (...params: any[]) => any): void;

declare class Weapp {

    reportFormId(formId: string): void;

    uploadTempFile(openId: string, tempFilePath: string, ossConfig: any): Promise<any>;

    bindPhone(options: {
        code: string;
        iv: string;
        encryptedData: string;
        allowMerge: boolean;
    }): any;

    getVersion(): string;
}

declare class WxH5 {

    config(options: {
        jsApiList?: Array<any>;
        debug?: boolean;
        url?: string;
        channelId?: string;
        isNotDelegated?: string;
    }): Promise<any>;

    updateShareData(options: {
        title: string;
        desc: string;
        link: string;
        imgUrl: string;
        needOauth?: boolean;
        oauthConfig?: {
            scope?: string;
            isTest?: boolean;
        };
    }): Promise<any>;

    updateAppMessageShareData(options: {
        title: string;
        desc: string;
        link: string;
        imgUrl: string;
        needOauth?: boolean;
        oauthConfig?: {
            scope?: string;
            isTest?: boolean;
        };
    }): Promise<any>;

    updateTimelineShareData(options: {
        title: string;
        link: string;
        imgUrl: string;
        needOauth?: boolean;
        oauthConfig?: {
            scope?: string;
            isTest?: boolean;
        };
    }): Promise<any>;

    onMenuShareAppMessage(options: {
        title: string;
        desc: string;
        link: string;
        imgUrl: string;
        type?: string;
        dataUrl?: string;
        needOauth?: boolean;
        oauthConfig?: {
            scope?: string;
            isTest?: boolean;
        };
    }): void;

    onMenuShareTimeline(options: {
        title: string;
        link: string;
        imgUrl: string;
        needOauth?: boolean;
        oauthConfig?: {
            scope?: string;
            isTest?: boolean;
        };
    }): void;
}

declare class WxWeapp {
}


export default Mai;
